using System;
using System.Collections.Generic;
using System.IO;


/**
 * DarkRoom: if you don't have the flashlight,
 * you can't do anything except exit via the exitdir.
 * Note that the flashlight can be lit *only* in the DarkRoom.
 * 
 * @author (Peter Dordal) 
 * @version (Spring 2006)
 */
public class DarkRoom : Room
{
    // instance variables - replace the example below with your own
    private string exitdir;
    private List<Item> inventory;

    /**
     * If you don't have a light, the only visible way out is exitdir
     */
    public DarkRoom(string exitdirection, string desc, List<Item> inv) : base(desc)
    {
        exitdir = exitdirection;
        inventory = inv;
    }

    /**
     * getShortDescription prints the dark description if there is no light.
     */
    public override string getShortDescription() {
        if (Light.haslight(inventory)) 
            return base.getShortDescription();
        string desc = "in a pitch-dark place! You need a light!";
        return desc;
    }
    
    /**
     * getLongDescription doesn't print all the exits if it's dark, or the contents.
     */
    public override string getLongDescription() {
        if (Light.haslight(inventory))
            return base.getLongDescription();
        string desc1 = getShortDescription();
        string desc2 = "The only way out you can see is a dimly lit exit to the " + exitdir;
        return desc1 + "\n" + desc2;
    }

    /**
     * respond: LIGHT FLASHLIGHT and TAKE <anything> (TAKE is disabled in the dark!)
     * Arguably LIGHT FLASHLIGHT should be moved to elsewhere.
     * Class demo: Respond to LIGHT <anything>, where we check if
     * <anything> is on the inventory and, if so, if it's a Light.
     * GO only allows going out the exitdir if we don't have the light.
     * Note that this is NOT necessarily the same as the way we came in!
     * What would it take to implement the latter?
     */
    public override Room respond(Command c, List<Item> inventory) {
        string commandWord = c.getCommandWord();
        string dobject = c.getSecondWord();
        if (commandWord == "go" 
            && dobject != exitdir
            && !Light.haslight(inventory) )
        {
            Console.WriteLine("It's too dark to see any exit that way!");
            return null;
        }
        
        if (commandWord == "light") {
            Item f = Item.findByName(dobject, inventory);
            if (f == null) {
                Console.WriteLine("you don't have the " + dobject);
                return null;
            }
            if (f is Light) {
                Light fl = (Light) f;
                fl.light();
                Console.WriteLine("The " + dobject + " is now lit");
                Console.WriteLine(getLongDescription());
                return null;
            } else {
                Console.WriteLine("You can't light the " + dobject + "!");
                return null;
            }
            
        } 
        if (commandWord == "take") {
            if (Light.haslight(inventory)) { 
                return base.respond(c, inventory);
            } else {
                Console.WriteLine("It's too dark to see anything to take!");
                return null;
            }
        } 
        
        return base.respond(c, inventory);
        
    }
    
    /* */
}
